@@ -1,42 +1,10 @@
 <?php
 /*
- * Copyright 2005 - 2013  Zarafa B.V.
+ * Copyright 2005 - 2016  Zarafa B.V. and its licensors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation with the following additional
- * term according to sec. 7:
- *
- * According to sec. 7 of the GNU Affero General Public License, version
- * 3, the terms of the AGPL are supplemented with the following terms:
- *
- * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
- * the Program under the AGPL does not imply a trademark license.
- * Therefore any rights, title and interest in our trademarks remain
- * entirely with us.
- *
- * However, if you propagate an unmodified version of the Program you are
- * allowed to use the term "Zarafa" to indicate that you distribute the
- * Program. Furthermore you may use our trademarks where it is necessary
- * to indicate the intended purpose of a product or service provided you
- * use it in accordance with honest practices in industrial or commercial
- * matters.  If you want to propagate modified versions of the Program
- * under the name "Zarafa" or "Zarafa Server", you may only do so if you
- * have a written permission by Zarafa B.V. (to acquire a permission
- * please contact Zarafa at trademark@zarafa.com).
- *
- * The interactive user interface of the software displays an attribution
- * notice containing the term "Zarafa" and/or the logo of Zarafa.
- * Interactive user interfaces of unmodified and modified versions must
- * display Appropriate Legal Notices according to sec. 5 of the GNU
- * Affero General Public License, version 3, when you propagate
- * unmodified or modified versions of the Program. In accordance with
- * sec. 7 b) of the GNU Affero General Public License, version 3, these
- * Appropriate Legal Notices must retain the logo of Zarafa or display
- * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons. The use of the logo
- * of Zarafa in Legal Notices is allowed for unmodified and modified
- * versions of the software.
+ * as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -46,6 +14,7 @@
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
+ * Consult LICENSE file for details
  */
 
     class TaskRecurrence extends BaseRecurrence
@@ -55,7 +24,7 @@
          */
         var $tz = false;
 
-        function TaskRecurrence($store, $message)
+        function __construct($store, $message)
         {
             $this->store = $store;
             $this->message = $message;
@@ -104,7 +73,7 @@
 
             $this->proptags = getPropIdsFromStrings($store, $properties);
 
-            parent::BaseRecurrence($store, $message, $properties);
+            parent::__construct($store, $message, $properties);
         }
 
         /**
@@ -329,13 +298,13 @@
             mapi_savechanges($newMessage);
 
             // Update body of original message
-            $msgbody = mapi_message_openproperty($this->message, PR_BODY);
+            $msgbody = mapi_openproperty($this->message, PR_BODY);
             $msgbody = trim($this->windows1252_to_utf8($msgbody), "\0");
             $separator = "------------\r\n";
 
             if (!empty($msgbody) && strrpos($msgbody, $separator) === false) {
                 $msgbody = $separator . $msgbody;
-                $stream = mapi_openpropertytostream($this->message, PR_BODY, MAPI_CREATE | MAPI_MODIFY);
+                $stream = mapi_openproperty($this->message, PR_BODY, IID_IStream, 0, MAPI_CREATE | MAPI_MODIFY);
                 mapi_stream_setsize($stream, strlen($msgbody));
                 mapi_stream_write($stream, $msgbody);
                 mapi_stream_commit($stream);
