@@ -1,42 +1,10 @@
 <?php
 /*
- * Copyright 2005 - 2013  Zarafa B.V.
+ * Copyright 2005 - 2016  Zarafa B.V. and its licensors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation with the following additional
- * term according to sec. 7:
- *
- * According to sec. 7 of the GNU Affero General Public License, version
- * 3, the terms of the AGPL are supplemented with the following terms:
- *
- * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
- * the Program under the AGPL does not imply a trademark license.
- * Therefore any rights, title and interest in our trademarks remain
- * entirely with us.
- *
- * However, if you propagate an unmodified version of the Program you are
- * allowed to use the term "Zarafa" to indicate that you distribute the
- * Program. Furthermore you may use our trademarks where it is necessary
- * to indicate the intended purpose of a product or service provided you
- * use it in accordance with honest practices in industrial or commercial
- * matters.  If you want to propagate modified versions of the Program
- * under the name "Zarafa" or "Zarafa Server", you may only do so if you
- * have a written permission by Zarafa B.V. (to acquire a permission
- * please contact Zarafa at trademark@zarafa.com).
- *
- * The interactive user interface of the software displays an attribution
- * notice containing the term "Zarafa" and/or the logo of Zarafa.
- * Interactive user interfaces of unmodified and modified versions must
- * display Appropriate Legal Notices according to sec. 5 of the GNU
- * Affero General Public License, version 3, when you propagate
- * unmodified or modified versions of the Program. In accordance with
- * sec. 7 b) of the GNU Affero General Public License, version 3, these
- * Appropriate Legal Notices must retain the logo of Zarafa or display
- * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons. The use of the logo
- * of Zarafa in Legal Notices is allowed for unmodified and modified
- * versions of the software.
+ * as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -46,9 +14,9 @@
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
+ * Consult LICENSE file for details
  */
 
-
     /*
     * In general
     *
@@ -130,7 +98,7 @@
          * @param $message message MAPI Message to which the task request referes (can be an email or a task)
          * @param $session session MAPI Session which is used to open tasks folders for delegated task requests or responses
          */
-        function TaskRequest($store, $message, $session) {
+        function __construct($store, $message, $session) {
             $this->store = $store;
             $this->message = $message;
             $this->session = $session;
@@ -345,7 +313,7 @@
 
             // Set Body
             $body = $this->getBody();
-            $stream = mapi_openpropertytostream($outgoing, PR_BODY, MAPI_CREATE | MAPI_MODIFY);
+            $stream = mapi_openproperty($outgoing, PR_BODY, IID_IStream, 0, MAPI_MODIFY | MAPI_CREATE);
             mapi_stream_setsize($stream, strlen($body));
             mapi_stream_write($stream, $body);
             mapi_stream_commit($stream);
@@ -519,7 +487,7 @@
 
                 $this->setRecipientsForResponse($outgoing, tdmtTaskUpd, true);
                 $body = $this->getBody();
-                $stream = mapi_openpropertytostream($outgoing, PR_BODY, MAPI_CREATE | MAPI_MODIFY);
+                $stream = mapi_openproperty($outgoing, PR_BODY, IID_IStream, 0, MAPI_CREATE | MAPI_MODIFY);
                 mapi_stream_setsize($stream, strlen($body));
                 mapi_stream_write($stream, $body);
                 mapi_stream_commit($stream);
@@ -665,7 +633,7 @@
 
             // Set Body
             $body = $this->getBody();
-            $stream = mapi_openpropertytostream($outgoing, PR_BODY, MAPI_CREATE | MAPI_MODIFY);
+            $stream = mapi_openproperty($outgoing, PR_BODY, IID_IStream, 0, MAPI_CREATE | MAPI_MODIFY);
             mapi_stream_setsize($stream, strlen($body));
             mapi_stream_write($stream, $body);
             mapi_stream_commit($stream);
@@ -962,7 +930,7 @@
             if (isset($msgProps[$this->props['mileage']])) $body .= "\n" . _("Mileage") . ":\t". $msgProps[$this->props['mileage']];
             $body .="\n";
 
-            $content = mapi_message_openproperty($this->message, PR_BODY);
+            $content = mapi_openproperty($this->message, PR_BODY);
             $body .= "\n". trim($content, "\0");
 
             return $body;
