@@ -9,29 +9,11 @@
 *
 * Created   :   14.05.2010
 *
-* Copyright 2007 - 2015 Zarafa Deutschland GmbH
+* Copyright 2007 - 2016 Zarafa Deutschland GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License, version 3,
-* as published by the Free Software Foundation with the following additional
-* term according to sec. 7:
-*
-* According to sec. 7 of the GNU Affero General Public License, version 3,
-* the terms of the AGPL are supplemented with the following terms:
-*
-* "Zarafa" is a registered trademark of Zarafa B.V.
-* "Z-Push" is a registered trademark of Zarafa Deutschland GmbH
-* The licensing of the Program under the AGPL does not imply a trademark license.
-* Therefore any rights, title and interest in our trademarks remain entirely with us.
-*
-* However, if you propagate an unmodified version of the Program you are
-* allowed to use the term "Z-Push" to indicate that you distribute the Program.
-* Furthermore you may use our trademarks where it is necessary to indicate
-* the intended purpose of a product or service provided you use it in accordance
-* with honest practices in industrial or commercial matters.
-* If you want to propagate modified versions of the Program under the name "Z-Push",
-* you may only do so if you have a written permission by Zarafa Deutschland GmbH
-* (to acquire a permission please contact Zarafa at trademark@zarafa.com).
+* as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -46,9 +28,6 @@
 
 require_once 'vendor/autoload.php';
 
-if (!defined('ZPUSH_CONFIG')) define('ZPUSH_CONFIG', 'config.php');
-include_once(ZPUSH_CONFIG);
-
 /**
  * //TODO resync of single folders of a users device
  */
@@ -58,6 +37,10 @@ include_once(ZPUSH_CONFIG);
  */
     define('BASE_PATH_CLI',  dirname(__FILE__) ."/");
     set_include_path(get_include_path() . PATH_SEPARATOR . BASE_PATH_CLI);
+
+    if (!defined('ZPUSH_CONFIG')) define('ZPUSH_CONFIG', BASE_PATH_CLI . 'config.php');
+    include_once(ZPUSH_CONFIG);
+
     try {
         ZPush::CheckConfig();
         ZPushAdminCLI::CheckEnv();
@@ -276,12 +259,25 @@ class ZPushAdminCLI {
                 self::$command = self::COMMAND_CLEARLOOP;
                 break;
 
-            // clear loop detection data
+            // fix states
             case "fixstates":
             case "fix":
                 self::$command = self::COMMAND_FIXSTATES;
                 break;
 
+            // hidden feature to run fixstates after upgrading the packages - this is called from postinst only
+            case "fixstates-upgrade":
+                // don't execute fixstates during upgrade if IGNORE_FIXSTATES_ON_UPGRADE is set to true
+                if (!defined('IGNORE_FIXSTATES_ON_UPGRADE') || IGNORE_FIXSTATES_ON_UPGRADE == false) {
+                    self::$command = self::COMMAND_FIXSTATES;
+                }
+                else {
+                    // print warning and exit gracefully
+                    echo "\nZ-Push: Not executing 'fixstates' as IGNORE_FIXSTATES_ON_UPGRADE is set. You should execute 'z-push-admin -a fixstates' manually!\n\n";
+                    exit(0);
+                }
+                break;
+
 
             default:
                 self::UsageInstructions();
@@ -746,7 +742,7 @@ class ZPushAdminCLI {
             echo ZLog::GetLastMessage(LOGLEVEL_ERROR) . "\n";
 
         echo "\tChecking flags of shared folders: ";
-        if (($stat = ZPushAdmin::FixStatesAdditionalFolderFlags()) !== false)
+        if (($stat = ZPushAdmin::FixStatesAdditionalFolders()) !== false)
             printf("Devices: %d - Devices with additional folders: %d - Fixed: %d\n",  $stat[0], $stat[1], $stat[2]);
         else
             echo ZLog::GetLastMessage(LOGLEVEL_ERROR) . "\n";
@@ -762,7 +758,8 @@ class ZPushAdminCLI {
      * @access private
      */
     static private function printDeviceData($deviceId, $user) {
-        $device = ZPushAdmin::GetDeviceDetails($deviceId, $user);
+        global $additionalFolders;
+        $device = ZPushAdmin::GetDeviceDetails($deviceId, $user, true);
 
         if (! $device instanceof ASDevice) {
             echo sprintf("Folder resync failed: %s\n", ZLog::GetLastMessage(LOGLEVEL_ERROR));
@@ -783,7 +780,7 @@ class ZPushAdminCLI {
                 switch($type) {
                     case SYNC_FOLDER_TYPE_APPOINTMENT:
                     case SYNC_FOLDER_TYPE_USER_APPOINTMENT:
-                        if (KOE_GAB_NAME != "" && $name == KOE_GAB_NAME) {
+                        if ($name == KOE_GAB_NAME) {
                             $gentype = "GAB";
                         }
                         else {
@@ -827,6 +824,46 @@ class ZPushAdminCLI {
         }
         if (!$folderinfo) $folderinfo = "None available";
 
+        // additional folders
+        $addFolders = array();
+        $sharedFolders = $device->GetAdditionalFolders();
+        array_walk($sharedFolders, function (&$key) { $key["origin"] = 'Shared'; });
+        // $additionalFolders comes directly from the config
+        array_walk($additionalFolders, function (&$key) { $key["origin"] = 'Configured'; });
+        foreach(array_merge($additionalFolders,$sharedFolders) as $df) {
+            $df['additional'] = '';
+            $syncfolderid = $device->GetFolderIdForBackendId($df['folderid'], false, false, null);
+            switch($df['type']) {
+                case SYNC_FOLDER_TYPE_USER_APPOINTMENT:
+                    if ($df['name'] == KOE_GAB_NAME) {
+                        $gentype = "GAB";
+                    }
+                    else {
+                        $gentype = "Calendar";
+                    }
+                    break;
+                case SYNC_FOLDER_TYPE_USER_CONTACT:
+                    $gentype = "Contact";
+                    break;
+                case SYNC_FOLDER_TYPE_USER_TASK:
+                    $gentype = "Task";
+                    break;
+                case SYNC_FOLDER_TYPE_USER_NOTE:
+                    $gentype = "Note";
+                    break;
+                default:
+                    $gentype = "Email";
+                    break;
+            }
+            if ($device->GetFolderType($syncfolderid) == SYNC_FOLDER_TYPE_UNKNOWN) {
+                $df['additional'] = "(KOE patching incomplete)";
+            }
+            $df['type'] = $gentype;
+            $df['synched'] = ($device->GetFolderUUID($syncfolderid)) ? 'Active' : 'Inactive (not yet synchronized or no permissions)';
+            $addFolders[] = $df;
+        }
+        $addFoldersTotal = !empty($addFolders) ? count($addFolders) : 'none';
+
         echo "-----------------------------------------------------\n";
         echo "DeviceId:\t\t$deviceId\n";
         echo "Device type:\t\t". ($device->GetDeviceType() !== ASDevice::UNDEFINED ? $device->GetDeviceType() : "unknown") ."\n";
@@ -878,6 +915,16 @@ class ZPushAdminCLI {
                 }
             }
         }
+        echo "Additional Folders:\t$addFoldersTotal\n";
+        foreach ($addFolders as $folder) {
+            if (strlen($folder['store']) > 14) {
+                $folder['store'] = substr($folder['store'], 0, 12) . "..";
+            }
+            if (strlen($folder['name']) > 20) {
+                $folder['name'] = substr($folder['name'], 0, 18) . "..";
+            }
+            printf("\t%s %s %s %s %s %s\n", str_pad($folder['origin'], 10), str_pad($folder['type'], 8), str_pad($folder['store'], 14), str_pad($folder['name'], 20), $folder['synched'], $folder['additional']);
+        }
         echo "Status:\t\t\t";
         switch ($device->GetWipeStatus()) {
             case SYNC_PROVISION_RWSTATUS_OK:
@@ -907,6 +954,7 @@ class ZPushAdminCLI {
             echo "\tVersion:\t". $device->GetKoeVersion() ."\n";
             echo "\tBuild:\t\t". $device->GetKoeBuild() ."\n";
             echo "\tBuild Date:\t". strftime("%Y-%m-%d %H:%M",$device->GetKoeBuildDate()) ."\n";
+            echo "\tCapabilities:\t". (count($device->GetKoeCapabilities()) ? implode(',', $device->GetKoeCapabilities()) : 'unknown') ."\n";
         }
 
         echo "Attention needed:\t";
